pub struct ListBucketsPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListBucketsPaginator
This is created with .items()
Implementations
Sourceimpl ListBucketsPaginatorItems
impl ListBucketsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<Bucket, SdkError<ListBucketsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<Bucket, SdkError<ListBucketsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().